Index: pkg/mac/README.txt
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- pkg/mac/README.txt	(revision b7dad25d3eb29fae05fef4f161dea644f080276f)
+++ pkg/mac/README.txt	(date 1587980299989)
@@ -4,23 +4,23 @@
 Required Packages (Either build the sources or get them from macports or similar):
 
 1. Python installation
-  - Python 2.7 or 3.4+ or above from https://www.python.org/
+  - Python 3.4+ or above from https://www.python.org/
 
 2. QT installation
-  - Qt 4 or 5 from http://www.qt.io/
+  - Qt 5 from http://www.qt.io/
 
 3. PostgreSQL installation
-  - PostgreSQL 9.1 or above from http://www.postgresql.org/
+  - PostgreSQL 9.5 or above from http://www.postgresql.org/
 
 Building:
 
 1. Set the PYTHON_HOME environment variable to the Python root installation directory, e.g.
 
-   export PYTHON_HOME=/System/Library/Frameworks/Python.framework/Versions/2.7
+   export PYTHON_HOME=/opt/local
 
 2. Set the QTDIR environment variable to the QT root installation directory, e.g.
 
-   export QTDIR=~/Qt/5.5/clang_64
+   export QTDIR=~/Qt/5.8/clang_64
 
 3. Set the PGDIR environment variable to the PostgreSQL installation directory, e.g.
 
Index: pkg/mac/framework.conf.in
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- pkg/mac/framework.conf.in	(revision b7dad25d3eb29fae05fef4f161dea644f080276f)
+++ pkg/mac/framework.conf.in	(date 1587980299992)
@@ -1,8 +1,8 @@
 # copy this file to framework.conf, and edit the values below to reflect your environment
 # (versions of Python/Qt used)
 
-PYTHON_SHORT_VERSION=2.7
-PYTHON_FULL_VERSION=2.7.10
+PYTHON_SHORT_VERSION=3.6
+PYTHON_FULL_VERSION=3.6.10
 
 QT_SHORT_VERSION=5.8
 QT_FULL_VERSION=5.8.0
Index: pkg/mac/build.sh
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- pkg/mac/build.sh	(revision b7dad25d3eb29fae05fef4f161dea644f080276f)
+++ pkg/mac/build.sh	(date 1587980726972)
@@ -16,39 +16,29 @@
     exit 1
 fi
 
-export SYSTEM_PYTHON=0
 if [ "x${PYTHON_HOME}" == "x" ]; then
-    echo "PYTHON_HOME not set. Setting it to default"
-    export PYTHON_HOME=/System/Library/Frameworks/Python.framework/Versions/2.7
-    export PYTHON_VERSION=27
-    export SYSTEM_PYTHON=1
+    echo "PYTHON_HOME not set. It must be set, and pointing to a Python 3 installation."
+    exit 1
 fi
 
 # Check if Python is working and calculate PYTHON_VERSION
-if ${PYTHON_HOME}/bin/python2 -V > /dev/null 2>&1; then
-    export PYTHON_VERSION=`${PYTHON_HOME}/bin/python2 -V 2>&1 | awk '{print $2}' | cut -d"." -f1-2 | sed 's/\.//'`
-elif ${PYTHON_HOME}/bin/python3 -V > /dev/null 2>&1; then
+if ${PYTHON_HOME}/bin/python3 -V > /dev/null 2>&1; then
     export PYTHON_VERSION=`${PYTHON_HOME}/bin/python3 -V 2>&1 | awk '{print $2}' | cut -d"." -f1-2 | sed 's/\.//'`
 else
     echo "Error: Python installation missing!"
     exit 1
 fi
 
-if [ "${PYTHON_VERSION}" -gt "37" -a "${PYTHON_VERSION}" -lt "27" ]; then
-    echo "Python version not supported"
+if [ "${PYTHON_VERSION}" -gt "38" -a "${PYTHON_VERSION}" -lt "34" ]; then
+    echo "Python version not supported."
     exit 1
 fi
 
-if [ "${PYTHON_VERSION}" -ge "30" ]; then
-    export PYTHON=${PYTHON_HOME}/bin/python3
-    export PIP=pip3
-else
-    export PYTHON=${PYTHON_HOME}/bin/python2
-    export PIP=pip
-fi
+export PYTHON=${PYTHON_HOME}/bin/python3
+export PIP=pip3
 
 if [ "x${QTDIR}" == "x" ]; then
-    echo "QTDIR not set. Setting it to default"
+    echo "QTDIR not set. Setting it to default."
     export QTDIR=~/Qt/5.8/clang_64
 fi
 export QMAKE=${QTDIR}/bin/qmake
@@ -58,7 +48,7 @@
 fi
 
 if [ "x${PGDIR}" == "x" ]; then
-    echo "PGDIR not set. Setting it to default"
+    echo "PGDIR not set. Setting it to default."
     export PGDIR=/usr/local/pgsql
 fi
 
@@ -88,11 +78,7 @@
     test -d ${BUILDROOT} || mkdir ${BUILDROOT} || exit 1
     cd ${BUILDROOT}
 
-    if [ ${SYSTEM_PYTHON} -eq 1 ]; then
-        test -d ${VIRTUALENV} || virtualenv -p ${PYTHON} ${VIRTUALENV} || exit 1
-    else
-        test -d ${VIRTUALENV} || virtualenv -p ${PYTHON} --always-copy ${VIRTUALENV} || exit 1
-    fi
+    test -d ${VIRTUALENV} || virtualenv -p ${PYTHON} --always-copy ${VIRTUALENV} || exit 1
 
     source ${VIRTUALENV}/bin/activate
     ${PIP} install --no-cache-dir --no-binary psycopg2 -r ${SOURCEDIR}/requirements.txt || { echo PIP install failed. Please resolve the issue and rerun the script; exit 1; }
@@ -114,11 +100,7 @@
     for FULLPATH in ${PYSYSLIB_PATH}/*.py; do
         FILE=${FULLPATH##*/}
         if [ ! -e ${FILE} ]; then
-           if [ ${SYSTEM_PYTHON} -eq 1 ]; then
-               ln -s ${FULLPATH} ${FILE}
-           else
-               cp ${FULLPATH} ${FILE}
-           fi
+           cp ${FULLPATH} ${FILE}
         fi
     done
 
@@ -127,11 +109,7 @@
         FULLPATH=${FULLPATH%*/}
         FILE=${FULLPATH##*/}
         if [ ! -e ${FILE} ]; then
-            if [ ${SYSTEM_PYTHON} -eq 1 ]; then
-                ln -s ${FULLPATH} ${FILE}
-            else
-                cp -R ${FULLPATH} ${FILE}
-            fi
+            cp -R ${FULLPATH} ${FILE}
         fi
     done
 
@@ -178,17 +156,11 @@
     # copy Python private environment to app bundle
     cp -PR ${BUILDROOT}/${VIRTUALENV} "${BUILDROOT}/${APP_BUNDLE_NAME}/Contents/Resources/" || exit 1
 
-    if [ ${SYSTEM_PYTHON} -eq 1 ]; then
-        # remove the python bin and include from app bundle as it is not needed
-        rm -rf "${BUILDROOT}/${APP_BUNDLE_NAME}/Contents/Resources/${VIRTUALENV}/bin" "${BUILDROOT}/${APP_BUNDLE_NAME}/Contents/Resources/${VIRTUALENV}/include"
-        rm -rf "${BUILDROOT}/${APP_BUNDLE_NAME}/Contents/Resources/${VIRTUALENV}/.Python"
-    fi
-
     # Remove any TCL-related files that may cause us problems
     find "${BUILDROOT}/${APP_BUNDLE_NAME}/Contents/Resources/${VIRTUALENV}/" -name "_tkinter*" -print0 | xargs -0 rm -f
 
     # run complete-bundle to copy the dependent libraries and frameworks and fix the rpaths
-    ./complete-bundle.sh "${BUILDROOT}/${APP_BUNDLE_NAME}" || { echo complete-bundle.sh failed; exit 1; }
+    # ./complete-bundle.sh "${BUILDROOT}/${APP_BUNDLE_NAME}" || { echo complete-bundle.sh failed; exit 1; }
 
     pushd ${SOURCEDIR}/web
         yarn install || exit 1
